@@ -7,17 +7,9 @@ except ImportError:
 	if os.path.exists("/usr/bin/pip3"): os.system(f"/usr/bin/pip3 install syst3m --user {OWNER}")
 	else: os.system(f"pip3 install syst3m")
 
-# source.	
-ALIAS = "ssht00ls"
-SOURCE_NAME = "ssht00ls"
-SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=3)
-BASE = syst3m.defaults.get_source_path(SOURCE_PATH)
-OS = syst3m.defaults.check_operating_system(supported=["linux", "osx"])
-syst3m.defaults.check_alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+# imports.
+try: 
 
-# safe imports.
-def imports():
-	
 	# imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
 
@@ -26,16 +18,30 @@ def imports():
 	from r3sponse import r3sponse
 	import cl1, syst3m, encrypti0n, netw0rk
 
-	#
-def safe_imports(reattempt=True, imports=imports):
-	try: imports()
-	except ImportError as e:
-		if not reattempt: raise ImportError(e)
-		if os.path.exists("/usr/bin/pip3"): 
-			os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
-		else:
-			os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
-safe_imports()
+# download.
+except ImportError as e:
+	import os
+	if os.path.exists("/usr/bin/pip3"): 
+		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.get_source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+	else:
+		os.system(f"pip3 install -r {syst3m.defaults.get_source_path(__file__, back=3)}/requirements/requirements.txt")
+
+	# imports.
+	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
+
+	# inc imports.
+	from fil3s import Files, Formats
+	from r3sponse import r3sponse
+	import cl1, syst3m, encrypti0n, netw0rk
+
+
+# source.	
+ALIAS = "ssht00ls"
+SOURCE_NAME = "ssht00ls"
+SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=3)
+BASE = syst3m.defaults.get_source_path(SOURCE_PATH)
+OS = syst3m.defaults.check_operating_system(supported=["linux", "osx"])
+syst3m.defaults.check_alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
 OWNER = os.environ.get("USER")
@@ -75,7 +81,7 @@ for dir, permission in [
 
 # files.
 DATABASE = Files.Directory(path=f"{HOME}/.{ALIAS}")
-CONFIG = Files.Dictionary(path=DATABASE.join("config",""), load=True, default={
+CONFIG = Files.Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True, default={
 	"aliases":{
 		"example.com (key's are optional)":{
 			"user":"administrator",
@@ -83,7 +89,8 @@ CONFIG = Files.Dictionary(path=DATABASE.join("config",""), load=True, default={
 			"public_port":22,
 			"private_ip":"84.84.123.192",
 			"private_port":22,
-			"key":"~/keys/exmaple.com/administrator/private_key",
+			"private_key":"~/keys/example.com/administrator/private_key",
+			"public_key":"~/keys/example.com/administrator/public_key",
 			"passphrase":None,
 			"smart_card":False,
 			"pin":None,
@@ -96,13 +103,7 @@ CONFIG = Files.Dictionary(path=DATABASE.join("config",""), load=True, default={
 		"public_key":None,
 		"private_key":None,
 	},
-	"includes":[], # import other configuration files (overwrites all existing keys).
 })
-for i in CONFIG.dictionary["includes"]:
-	i = syst3m.env.fill(i)
-	if not os.path.exists(i):
-		raise FileNotFoundError(f"ssht00ls config include file [{i}] does not exist.")
-	CONFIG.dictionary = Files.Dictionary(path=False, dictionary=CONFIG.dictionary).append(Files.Dictionary(path=i, load=True), sum=[], overwrite=["*"], banned=["includes"])
 
 # initialize cache.
 cache = syst3m.cache.Cache(
