@@ -5,6 +5,7 @@
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 from ssht00ls.classes.aliases import aliases
+from ssht00ls.classes.agent import agent
 
 # the ssync object class.
 class SSync(object):
@@ -150,6 +151,8 @@ class SSync(object):
 		forced=False,
 		# version control.
 		safe=False,
+		# accept new hosts keys.
+		accept_new_host_keys=True,
 	):	
 		# check alias.
 		response = aliases.check(alias)
@@ -162,7 +165,7 @@ class SSync(object):
 		if not response.success: return response
 		passphrase = response.decrypted.decode()
 		# tests.
-		response = ssht00ls.agent.add(path=CONFIG["aliases"][alias]["key"], passphrase=passphrase)
+		response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 		if not response["success"]: return response
 		response = utils.test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
@@ -195,6 +198,8 @@ class SSync(object):
 		forced=False,
 		# version control.
 		safe=False,
+		# accept new hosts keys.
+		accept_new_host_keys=True,
 	):
 		# check alias.
 		response = aliases.check(alias)
@@ -207,7 +212,7 @@ class SSync(object):
 		if not response.success: return response
 		passphrase = response.decrypted.decode()
 		# tests.
-		response = ssht00ls.agent.add(path=CONFIG["aliases"][alias]["key"], passphrase=passphrase)
+		response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 		if not response["success"]: return response
 		response = utils.test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
